@@ -25,6 +25,7 @@ getColNameOfClass <- function(df, class_name){
 #'   If agg_names is NULL will aggregate over all
 #'
 #' @importFrom magrittr %>%
+#' @importFrom rlang !!!
 #' @export
 aggregateGAData <- function(ga_data, 
                             agg_names=NULL,
@@ -49,20 +50,20 @@ aggregateGAData <- function(ga_data,
 
   ## metrics to take mean as per mean_regex
   meanAgg <- ga_data %>%
-    dplyr::select_(.dots = mean_selects) %>%
-    dplyr::group_by_(.dots=dots) %>%
+    dplyr::select(!!!mean_selects) %>%
+    dplyr::group_by(!!!dots) %>%
     dplyr::summarise_all(dplyr::funs(mean(., na.rm = TRUE))) %>% dplyr::ungroup()
   
   ## metrics to sum over
   sumAgg <- ga_data %>%
-    dplyr::select_(.dots = sum_selects) %>%
-    dplyr::group_by_(.dots=dots) %>%
+    dplyr::select(!!!sum_selects) %>%
+    dplyr::group_by(!!!dots) %>%
     dplyr::summarise_all(dplyr::funs(sum(., na.rm = TRUE))) %>% dplyr::ungroup()
   
   ## date dimensions take the first entry
   dateAgg <- ga_data %>%
-    dplyr::select_(.dots = date_selects) %>%
-    dplyr::group_by_(.dots=dots) %>%
+    dplyr::select(!!!date_selects) %>%
+    dplyr::group_by(!!!dots) %>%
     dplyr::summarise_all(dplyr::funs(min(., na.rm = TRUE))) %>% dplyr::ungroup()
   
   ## join up all the aggregations
