@@ -216,7 +216,7 @@ make_ga_4_req <- function(viewId,
 #'   the number of calls.
 #' 
 #' @inheritParams make_ga_4_req
-#' @param max Maximum number of rows to fetch. Defaults at 1000. Use -1 to fetch all results.
+#' @param max Maximum number of rows to fetch. Defaults at 1000. Use -1 to fetch all results. Ignored when \code{anti_sample=TRUE}.
 #' @param anti_sample If TRUE will split up the call to avoid sampling.
 #' @param anti_sample_batches "auto" default, or set to number of days per batch. 1 = daily.
 #' @param slow_fetch For large results this slows down the API requests to avoid 500 errors
@@ -271,6 +271,8 @@ google_analytics_4 <- function(viewId,
                                anti_sample_batches = "auto",
                                slow_fetch = FALSE){
   
+  # cache_call(cache)
+  
   max         <- as.integer(max)
   allResults  <- FALSE
   if(max < 0){
@@ -351,8 +353,7 @@ google_analytics_4 <- function(viewId,
   ## if batching, get the rest of the results now we now precise rowCount
   if(allResults){
     all_rows <- as.integer(attr(out, "rowCount"))
-    if(nrow(out) < all_rows){
-    # if(!is.null(out) && nrow(out) < all_rows){
+    if(!is.null(out) && nrow(out) < all_rows){
       ## create the remaining requests
       meta_batch_start_index2 <- seq(from=50000, to=all_rows, by=reqRowLimit)
       ## make a list of the requests
