@@ -15,20 +15,12 @@
   )
   
   toset <- !(names(op.googleAnalyticsR) %in% names(op))
-  
+  ## only set those not set already
   if(any(toset)) options(op.googleAnalyticsR[toset])
-  default_project_message()
-  invisible()
   
-}
-
-.onAttach <- function(libname, pkgname){
-  
-  needed <- c("https://www.googleapis.com/auth/analytics.readonly")
-
-  googleAuthR::gar_attach_auto_auth(needed, 
-                                    environment_var = "GA_AUTH_FILE", 
-                                    travis_environment_var = "TRAVIS_GA_AUTH_FILE")
+  ## override existing options
+  options(
+    googleAuthR.batch_endpoint = "https://www.googleapis.com/batch/analytics/v3")
   
   if(Sys.getenv("GA_CLIENT_ID") != ""){
     options(googleAuthR.client_id = Sys.getenv("GA_CLIENT_ID"))
@@ -46,6 +38,44 @@
     options(googleAuthR.webapp.client_id = Sys.getenv("GA_WEB_CLIENT_SECRET"))
   }
   
+  default_project_message()
+  
+  f <- function(req){
+    if(!is.null(req$content$reports)){
+      return(TRUE)
+    } else {
+      return(FALSE)
+    }}
+
+  googleAuthR::gar_cache_setup(invalid_func = f)
+  
+  invisible()
+  
+}
+
+.onAttach <- function(libname, pkgname){
+  
+  if(Sys.getenv("GA_CLIENT_ID") != ""){
+    options(googleAuthR.client_id = Sys.getenv("GA_CLIENT_ID"))
+  }
+  
+  if(Sys.getenv("GA_CLIENT_SECRET") != ""){
+    options(googleAuthR.client_secret = Sys.getenv("GA_CLIENT_SECRET"))
+  }
+  
+  if(Sys.getenv("GA_WEB_CLIENT_ID") != ""){
+    options(googleAuthR.webapp.client_id = Sys.getenv("GA_WEB_CLIENT_ID"))
+  }
+  
+  if(Sys.getenv("GA_WEB_CLIENT_SECRET") != ""){
+    options(googleAuthR.webapp.client_id = Sys.getenv("GA_WEB_CLIENT_SECRET"))
+  }
+  
+  needed <- c("https://www.googleapis.com/auth/analytics.readonly")
+  
+  googleAuthR::gar_attach_auto_auth(needed, 
+                                    environment_var = "GA_AUTH_FILE")
+  
   invisible()
   
 }
